@media screen and (min-width: 501px) and (max-width: 1199px) {

}

@media screen and (min-width: 501px) and (max-width: 1199px) {

}

@media screen and (min-width: 40.001em) and (max-width: 59.999em) {

}

@media screen and (min-width: 13.801rem) and (max-width: 51.2rem) {

}

@media screen and (min-width: 6.001in) and (max-width: 8.999in) {

}

@media screen and (min-width: 1px) and (max-width: 500.579px) {
}

@media screen and (width) and (min-width: 0.081px) and (max-width: 0.679px) {

}

/* height */
@media screen and (min-height: 501px) and (max-height: 1199px) {

}

@media screen and (min-height: 501px) and (max-height: 1199px) {

}

@media screen and (min-height: 40.001em) and (max-height: 59.999em) {

}

@media screen and (min-height: 13.8rem) and (max-height: 51.199rem) {

}

@media screen and (min-height: 6.001in) and (max-height: 8.999in) {

}

@media screen and (min-height: 1px) and (max-height: 500.579px) {
}

@media screen and (height) and (min-height: 0.081px) and (max-height: 0.679px) {

}
