@media screen and (width >= 500px) and (width <= 1200px) {

}

@media screen and (500px <= width <= 1200px) {

}

@media screen and (0 <= width <= 500.58px) {
}

@media screen and (width) and (.08px <= width <= 0.68px) {

}

/* height */
@media screen and (height >= 500px) and (height <= 1200px) {

}

@media screen and (500px <= height <= 1200px) {

}

@media screen and (0 <= height <= 500.58px) {
}

@media screen and (height) and (.08px <= height <= 0.68px) {

}
