@media screen and  (min-width: 500px)  and (max-width: 1200px) /* comment */{
  .bar {
    display: block;
  }
}

@media screen and (min-width: 500px) and (max-width: 1200px) /* comment */{
  .bar {
    display: block;
  }
}
