@media screen and

(min-width: 500px)
and
(max-width: 1200px) {
  .foo {
  	display: block;
  }
}

@media screen and

(min-width: 1200px) and (max-width: 500px)
and
(hover) {
  .bar {
  	display: block;
  }
}
