@media (min-width: 768px) and (max-width: 1023px) {}
@media (min-width: 768px) and (max-width: 1023px) {}

@media (min-width: 769px) and (max-width: 1024px) {}
@media (min-width: 769px) and (max-width: 1024px) {}

@media (min-width: 768px) and (max-width: 1024px) {}
@media (min-width: 768px) and (max-width: 1024px) {}

@media (min-width: 769px) and (max-width: 1023px) {}
@media (min-width: 769px) and (max-width: 1023px) {}
