@media screen and (min-width: 500px) and (height) {
  .bar {
    display: block;
  }
}

@media screen and (min-width: 500px) and (max-width: 1200px) and (height) {
  .bar {
    display: block;
  }
}

@media screen and (any-hover) and (min-width: 500px) and (device-width) {
  .bar {
    display: block;
  }
}

@media screen and (any-hover) and (min-width: 500px) and (device-width) {
  .bar {
    display: block;
  }
}
