@media screen and (min-color-index: 0) and (max-color-index: 8) {

}

@media screen and (min-color-index: 0) and (max-color-index: 8) {

}

@media screen and (color-index) and (min-color-index: 6) and (max-color-index: 256) {

}
