@media screen and (min-aspect-ratio: 1/1000) and (max-aspect-ratio: 16/9) {

}

@media screen and (min-aspect-ratio: 1 / 1000) and (max-aspect-ratio: 16  /  9) {

}

@media screen and (min-aspect-ratio: 0/0) and (max-aspect-ratio: 16/9) {
}

@media screen and (aspect-ratio) and (min-aspect-ratio: 1 / 1000) and (max-aspect-ratio: 16  /  9) {

}